==> ssp-center-api-0.0.8-lqs17-20170511.123945-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/AccountMonthReportDto.java <==
/**
 * Project Name:media-api File Name:AccountMonthReportDto.java Package Name:cn.com.duiba.tuia.media.api.dto
 * Date:2016年11月30日下午3:07:58 Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:AccountMonthReportDto <br/>
 * Function: 媒体账户月报表. <br/>
 * Date: 2016年11月30日 下午3:07:58 <br/>
 * 
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
public class AccountMonthReportDto implements Serializable {

    /** 序列号 */
    private static final long serialVersionUID = -2538845766007546810L;

    /** id */
    private Long              id;

    /** 媒体用户id */
    private Long              mediaId;

    /** 媒体id */
    private Long              appId;

    /** 广告id */
    private Long              slotId;

    /** 每月曝光数 */
    private Integer           exposureCount;

    /** 每月点击数 */
    private Integer           clickCount;

    /** 每月点击人数 */
    private Integer           clickCountUv;

    /** 每月发券量 */
    private Integer           launchCount;

    /** 广告有效点击量 */
    private Integer           efClickCount;

    /** 实际媒体分成(分) */
    private Long              consumeTotal;

    /** 预计分成(分) */
    private Long              exConsumeTotal;

    /** 每月广告消耗(分) */
    private Long              adConsume;

    /** 日期 */
    private Date              curDate;

    /** 结算状态：0-待结算，1-结算中，2-拒绝结算 3-已结算 */
    private Integer           settlementStatus;
    
    /**提现单号*/
    private Long              cashOrderId;
    
    /**审核拒绝原因*/
    private String            checkMsg;
    
    /**提现状态*/
    private Integer          cashStatus;
    

    /**
     * settlementStatus.
     *
     * @return the settlementStatus
     * @since JDK 1.6
     */
    public Integer getSettlementStatus() {
        return settlementStatus;
    }

    /**
     * settlementStatus.
     *
     * @param settlementStatus the settlementStatus to set
     * @since JDK 1.6
     */
    public void setSettlementStatus(Integer settlementStatus) {
        this.settlementStatus = settlementStatus;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.6
     */
    public Integer getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.6
     */
    public void setExposureCount(Integer exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.6
     */
    public Integer getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.6
     */
    public void setClickCount(Integer clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * launchCount.
     *
     * @return the launchCount
     * @since JDK 1.6
     */
    public Integer getLaunchCount() {
        return launchCount;
    }

    /**
     * launchCount.
     *
     * @param launchCount the launchCount to set
     * @since JDK 1.6
     */
    public void setLaunchCount(Integer launchCount) {
        this.launchCount = launchCount;
    }

    /**
     * efClickCount.
     *
     * @return the efClickCount
     * @since JDK 1.6
     */
    public Integer getEfClickCount() {
        return efClickCount;
    }

    /**
     * efClickCount.
     *
     * @param efClickCount the efClickCount to set
     * @since JDK 1.6
     */
    public void setEfClickCount(Integer efClickCount) {
        this.efClickCount = efClickCount;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.6
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.6
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public Date getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    /**
     * mediaId.
     *
     * @return the mediaId
     * @since JDK 1.6
     */
    public Long getMediaId() {
        return mediaId;
    }

    /**
     * mediaId.
     *
     * @param mediaId the mediaId to set
     * @since JDK 1.6
     */
    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * clickCountUv.
     *
     * @return the clickCountUv
     * @since JDK 1.6
     */
    public Integer getClickCountUv() {
        return clickCountUv;
    }

    /**
     * clickCountUv.
     *
     * @param clickCountUv the clickCountUv to set
     * @since JDK 1.6
     */
    public void setClickCountUv(Integer clickCountUv) {
        this.clickCountUv = clickCountUv;
    }

    /**
     * exConsumeTotal.
     *
     * @return the exConsumeTotal
     * @since JDK 1.6
     */
    public Long getExConsumeTotal() {
        return exConsumeTotal;
    }

    /**
     * exConsumeTotal.
     *
     * @param exConsumeTotal the exConsumeTotal to set
     * @since JDK 1.6
     */
    public void setExConsumeTotal(Long exConsumeTotal) {
        this.exConsumeTotal = exConsumeTotal;
    }

    /**
     * adConsume.
     *
     * @return the adConsume
     * @since JDK 1.6
     */
    public Long getAdConsume() {
        return adConsume;
    }

    /**
     * adConsume.
     *
     * @param adConsume the adConsume to set
     * @since JDK 1.6
     */
    public void setAdConsume(Long adConsume) {
        this.adConsume = adConsume;
    }
    
    /**
     * cashOrderId.
     *
     * @return the cashOrderId
     * @since JDK 1.6
     */
    public Long getCashOrderId() {
        return cashOrderId;
    }

    /**
     * cashOrderId.
     *
     * @param cashOrderId the cashOrderId to set
     * @since JDK 1.6
     */
    public void setCashOrderId(Long cashOrderId) {
        this.cashOrderId = cashOrderId;
    }
    
    /**
     * checkMsg.
     *
     * @return the checkMsg
     * @since JDK 1.6
     */
    public String getCheckMsg() {
        return checkMsg;
    }

    /**
     * checkMsg.
     *
     * @param checkMsg the checkMsg to set
     * @since JDK 1.6
     */
    public void setCheckMsg(String checkMsg) {
        this.checkMsg = checkMsg;
    }
    
    /**
     * cashStatus.
     *
     * @return the cashStatus
     * @since JDK 1.6
     */
    public Integer getCashStatus() {
        return cashStatus;
    }
    
    /**
     * cashStatus.
     *
     * @param cashStatus the cashStatus to set
     * @since JDK 1.6
     */
    public void setCashStatus(Integer cashStatus) {
        this.cashStatus = cashStatus;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> ssp-center-api-0.1.36-lqs4-20171210.114923-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/AccountMonthReportDto.java <==
/**
 * Project Name:media-api File Name:AccountMonthReportDto.java Package Name:cn.com.duiba.tuia.media.api.dto
 * Date:2016年11月30日下午3:07:58 Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 */

package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:AccountMonthReportDto <br/>
 * Function: 媒体账户月报表. <br/>
 * Date: 2016年11月30日 下午3:07:58 <br/>
 * 
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
public class AccountMonthReportDto implements Serializable {

    /** 序列号 */
    private static final long serialVersionUID = -2538845766007546810L;

    /** id */
    private Long              id;

    /** 媒体用户id */
    private Long              mediaId;

    /** 媒体id */
    private Long              appId;

    /** 广告id */
    private Long              slotId;

    /** 每月曝光数 */
    private Integer           exposureCount;

    /** 每月点击数 */
    private Integer           clickCount;

    /** 每月点击人数 */
    private Integer           clickCountUv;

    /** 每月发券量 */
    private Integer           launchCount;

    /** 广告有效点击量 */
    private Integer           efClickCount;

    /** 实际媒体分成(分) */
    private Long              consumeTotal;

    /** 预计分成(分) */
    private Long              exConsumeTotal;

    /** 每月广告消耗(分) */
    private Long              adConsume;

    /** 日期 */
    private Date              curDate;

    /** 结算状态：0-待结算，1-结算中，2-拒绝结算 3-已结算 */
    private Integer           settlementStatus;
    
    /**提现单号*/
    private Long              cashOrderId;
    
    /**提现状态*/
    private Integer           cashStatus;

    /**结算后媒体分成*/
    private Long              settledMediaDivide;

    /**媒体运营*/
    private String           mediaOperation;
    
    /**风控运营*/
    private String           riskControlOperation;
    
    /**修改时间*/
    private Date             gmtModified;
   
    /**运营结算时间*/
    private Date             cashTime;
    
    /**运营审核时间*/
    private Date             auditTime;

    /**
     * settlementStatus.
     *
     * @return the settlementStatus
     * @since JDK 1.6
     */
    public Integer getSettlementStatus() {
        return settlementStatus;
    }

    /**
     * settlementStatus.
     *
     * @param settlementStatus the settlementStatus to set
     * @since JDK 1.6
     */
    public void setSettlementStatus(Integer settlementStatus) {
        this.settlementStatus = settlementStatus;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.6
     */
    public Integer getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.6
     */
    public void setExposureCount(Integer exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.6
     */
    public Integer getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.6
     */
    public void setClickCount(Integer clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * launchCount.
     *
     * @return the launchCount
     * @since JDK 1.6
     */
    public Integer getLaunchCount() {
        return launchCount;
    }

    /**
     * launchCount.
     *
     * @param launchCount the launchCount to set
     * @since JDK 1.6
     */
    public void setLaunchCount(Integer launchCount) {
        this.launchCount = launchCount;
    }

    /**
     * efClickCount.
     *
     * @return the efClickCount
     * @since JDK 1.6
     */
    public Integer getEfClickCount() {
        return efClickCount;
    }

    /**
     * efClickCount.
     *
     * @param efClickCount the efClickCount to set
     * @since JDK 1.6
     */
    public void setEfClickCount(Integer efClickCount) {
        this.efClickCount = efClickCount;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.6
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.6
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * curDate.
     *
     * @return the curDate
     * @since JDK 1.6
     */
    public Date getCurDate() {
        return curDate;
    }

    /**
     * curDate.
     *
     * @param curDate the curDate to set
     * @since JDK 1.6
     */
    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    /**
     * mediaId.
     *
     * @return the mediaId
     * @since JDK 1.6
     */
    public Long getMediaId() {
        return mediaId;
    }

    /**
     * mediaId.
     *
     * @param mediaId the mediaId to set
     * @since JDK 1.6
     */
    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * clickCountUv.
     *
     * @return the clickCountUv
     * @since JDK 1.6
     */
    public Integer getClickCountUv() {
        return clickCountUv;
    }

    /**
     * clickCountUv.
     *
     * @param clickCountUv the clickCountUv to set
     * @since JDK 1.6
     */
    public void setClickCountUv(Integer clickCountUv) {
        this.clickCountUv = clickCountUv;
    }

    /**
     * exConsumeTotal.
     *
     * @return the exConsumeTotal
     * @since JDK 1.6
     */
    public Long getExConsumeTotal() {
        return exConsumeTotal;
    }

    /**
     * exConsumeTotal.
     *
     * @param exConsumeTotal the exConsumeTotal to set
     * @since JDK 1.6
     */
    public void setExConsumeTotal(Long exConsumeTotal) {
        this.exConsumeTotal = exConsumeTotal;
    }

    /**
     * adConsume.
     *
     * @return the adConsume
     * @since JDK 1.6
     */
    public Long getAdConsume() {
        return adConsume;
    }

    /**
     * adConsume.
     *
     * @param adConsume the adConsume to set
     * @since JDK 1.6
     */
    public void setAdConsume(Long adConsume) {
        this.adConsume = adConsume;
    }
    
    /**
     * cashOrderId.
     *
     * @return the cashOrderId
     * @since JDK 1.6
     */
    public Long getCashOrderId() {
        return cashOrderId;
    }

    /**
     * cashOrderId.
     *
     * @param cashOrderId the cashOrderId to set
     * @since JDK 1.6
     */
    public void setCashOrderId(Long cashOrderId) {
        this.cashOrderId = cashOrderId;
    }
    
    
    /**
     * cashStatus.
     *
     * @return the cashStatus
     * @since JDK 1.6
     */
    public Integer getCashStatus() {
        return cashStatus;
    }
    
    /**
     * cashStatus.
     *
     * @param cashStatus the cashStatus to set
     * @since JDK 1.6
     */
    public void setCashStatus(Integer cashStatus) {
        this.cashStatus = cashStatus;
    }

    public Long getSettledMediaDivide() {
        return settledMediaDivide;
    }

    public void setSettledMediaDivide(Long settledMediaDivide) {
        this.settledMediaDivide = settledMediaDivide;
    }
    
    public String getMediaOperation() {
        return mediaOperation;
    }

    
    public void setMediaOperation(String mediaOperation) {
        this.mediaOperation = mediaOperation;
    }

    
    public String getRiskControlOperation() {
        return riskControlOperation;
    }

    
    public void setRiskControlOperation(String riskControlOperation) {
        this.riskControlOperation = riskControlOperation;
    }

    
    public Date getGmtModified() {
        return gmtModified;
    }

    
    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
    
    
    public Date getCashTime() {
        return cashTime;
    }

    
    public void setCashTime(Date cashTime) {
        this.cashTime = cashTime;
    }

    
    public Date getAuditTime() {
        return auditTime;
    }
    
    public void setAuditTime(Date auditTime) {
        this.auditTime = auditTime;
    }


    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
